aboutsummaryrefslogtreecommitdiffstats
path: root/src/gamma-x-vidmode.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/gamma-x-vidmode.c')
-rw-r--r--src/gamma-x-vidmode.c34
1 files changed, 17 insertions, 17 deletions
diff --git a/src/gamma-x-vidmode.c b/src/gamma-x-vidmode.c
index 29e954e..a73f36f 100644
--- a/src/gamma-x-vidmode.c
+++ b/src/gamma-x-vidmode.c
@@ -15,8 +15,8 @@
* You should have received a copy of the GNU General Public License
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef HAVE_GAMMA_METHOD_X_VIDMODE
# error Compiling gamma-x-vidmode.c without HAVE_GAMMA_METHOD_X_VIDMODE
#endif
#include "gamma-x-vidmode.h"
@@ -38,8 +38,8 @@
void libgamma_x_vidmode_method_capabilities(libgamma_method_capabilities_t* restrict this)
{
char* restrict display = getenv("DISPLAY");
- this->crtc_information = CRTC_INFO_GAMMA_SIZE
- | CRTC_INFO_GAMMA_DEPTH;
+ this->crtc_information = LIBGAMMA_CRTC_INFO_GAMMA_SIZE
+ | LIBGAMMA_CRTC_INFO_GAMMA_DEPTH;
this->default_site_known = (display && *display);
this->multiple_sites = 1;
this->multiple_partitions = 1;
@@ -213,13 +213,13 @@ int libgamma_x_vidmode_get_crtc_information(libgamma_crtc_information_t* restric
{
#define _E(FIELD) ((fields & FIELD) ? LIBGAMMA_CRTC_INFO_NOT_SUPPORTED : 0)
- this->edid_error = _E(CRTC_INFO_EDID);
- this->width_mm_error = _E(CRTC_INFO_WIDTH_MM);
- this->height_mm_error = _E(CRTC_INFO_HEIGHT_MM);
- this->width_mm_edid_error = _E(CRTC_INFO_WIDTH_MM_EDID);
- this->height_mm_edid_error = _E(CRTC_INFO_HEIGHT_MM_EDID);
+ this->edid_error = _E(LIBGAMMA_CRTC_INFO_EDID);
+ this->width_mm_error = _E(LIBGAMMA_CRTC_INFO_WIDTH_MM);
+ this->height_mm_error = _E(LIBGAMMA_CRTC_INFO_HEIGHT_MM);
+ this->width_mm_edid_error = _E(LIBGAMMA_CRTC_INFO_WIDTH_MM_EDID);
+ this->height_mm_edid_error = _E(LIBGAMMA_CRTC_INFO_HEIGHT_MM_EDID);
this->gamma_size_error = 0;
- if ((fields & CRTC_INFO_GAMMA_SUPPORT))
+ if ((fields & LIBGAMMA_CRTC_INFO_GAMMA_SUPPORT))
{
Display* restrict connection = crtc->partition->site->data;
int stops;
@@ -232,16 +232,16 @@ int libgamma_x_vidmode_get_crtc_information(libgamma_crtc_information_t* restric
}
this->gamma_depth = 16;
this->gamma_depth_error = 0;
- this->gamma_support_error = _E(CRTC_INFO_GAMMA_SUPPORT);
- this->subpixel_order_error = _E(CRTC_INFO_SUBPIXEL_ORDER);
- this->active_error = _E(CRTC_INFO_ACTIVE);
- this->connector_name_error = _E(CRTC_INFO_CONNECTOR_NAME);
- this->connector_type_error = _E(CRTC_INFO_CONNECTOR_TYPE);
- this->gamma_error = _E(CRTC_INFO_GAMMA);
+ this->gamma_support_error = _E(LIBGAMMA_CRTC_INFO_GAMMA_SUPPORT);
+ this->subpixel_order_error = _E(LIBGAMMA_CRTC_INFO_SUBPIXEL_ORDER);
+ this->active_error = _E(LIBGAMMA_CRTC_INFO_ACTIVE);
+ this->connector_name_error = _E(LIBGAMMA_CRTC_INFO_CONNECTOR_NAME);
+ this->connector_type_error = _E(LIBGAMMA_CRTC_INFO_CONNECTOR_TYPE);
+ this->gamma_error = _E(LIBGAMMA_CRTC_INFO_GAMMA);
#undef _E
- return (fields & ~(CRTC_INFO_GAMMA_DEPTH | CRTC_INFO_GAMMA_SIZE)) ? -1 : this->gamma_size_error;
+ return (fields & ~(LIBGAMMA_CRTC_INFO_GAMMA_DEPTH | LIBGAMMA_CRTC_INFO_GAMMA_SIZE)) ? -1 : this->gamma_size_error;
}
@@ -15,8 +15,8 @@
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef HAVE_GAMMA_METHOD_X_VIDMODE
-# error Compiling gamma-x-vidmode.c without HAVE_GAMMA_METHOD_X_VIDMODE
+#ifndef HAVE_LIBGAMMA_METHOD_X_VIDMODE
+# error Compiling gamma-x-vidmode.c without HAVE_LIBGAMMA_METHOD_X_VIDMODE
#endif
#include "gamma-x-vidmode.h"